@@ -609,7 +609,7 @@ def member_report(member_id):
         sample = json.loads(sample)["data-point"]
 
         if "type" in sample and sample["type"] == "journal-article":
-            print(f"Appending {sample['DOI']}")
+            # print(f"Appending {sample['DOI']}")
 
             md5_doi = hashlib.md5(sample["DOI"].lower().encode()).hexdigest()
 
@@ -637,7 +637,7 @@ def member_report(member_id):
 
             except Exception as e:
                 print(e)
-                print(f"This DOI was excluded: {sample['DOI']}")
+                # print(f"This DOI was excluded: {sample['DOI']}")
 
     key = f"{REPORT_PATH}/members/{member_id}/preservation-report.json"
     unpreserved_key = f"{REPORT_PATH}/members/{member_id}/unpreserved.json"
